@@ -4,10 +4,10 @@ package Config::Simple::Conf;
 
 use strict;
 # Version number - cvs automagically updated.
-our $VERSION = $1 if('$Revision: 1.5 $' =~ /: ([\d\.]+)/);
+our $VERSION = $1 if('$Revision: 1.6 $' =~ /: ([\d\.]+)/);
 
 # Revision - cvs automagically updated
-our $REVISION = '$Id: Conf.pm,v 1.5 2016/04/25 17:26:38 cfaber Exp $';
+our $REVISION = '$Id: Conf.pm,v 1.6 2016/04/27 17:01:00 cfaber Exp $';
 
 # Ruckus Global Version Number
 
@@ -34,8 +34,8 @@ In many of my usage cases I want something like your standard .INI file format,
 
 	# Define an entry list and use the value from another section to complete
 	# the configuration
-	path = [core section: path]/abc
-	path = [core section: path]/xyz
+	path = [core section:path]/abc
+	path = [core section:path]/xyz
 
 Such a configuration would allow me to do two things, establish a core path argument, which is then used in other sections, and have a section with multiple duplicate entires as a list.
 
@@ -62,6 +62,38 @@ With the resulting output looking something like:
 		/root/to/my/stuff/abc
 		/root/to/my/stuff/xyz
 
+=head1 CONFIG FILE FORMAT
+
+Configuration files are defined as ascii text, with comments lines starting with a pound symbol B<#>, sections, keys, and values. Values may be macro entries referencing other configuration keys.
+
+=head2 SECTION
+
+A section is defined as a single line entry with double square brakets B<[section]>:
+
+	# Define a section
+	[section]
+
+=head2 KEYS
+
+Keys are defined within a section as lines with keyname = value type entry
+
+	# Define a value for keyname in section [section]
+	[section]
+	keyname = value
+
+=head2 USING A MACRO
+
+Macros are defined as square brakets with a section:key entry between them. These are automatically resolved to other configuration keys and those key values are utilized.
+
+Macros may B<NOT> utilize list entries as a macro value at this point.
+
+	# Define a value based on a macro
+	[section2]
+	key = [section:keyname]
+
+=head2 EXAMPLES
+
+See examples/ directory for various configuration file examples
 
 =head1 SYNOPSIS
 
@@ -71,10 +103,6 @@ my $conf = Config::Simple::Conf->new('/etc/Something/Example.conf');
 
 print $conf->value('global', 'example_key');
 
-=head1 CONFIGURATION FILE FORMAT
-
-See examples/ directory for various configuration file examples
-
 =head1 METHODS
 
 =head2 new()
